# Icons

This directory contains icons and assets for creating these.

To generate the icons, use `python3 make_icons.py`.

When adding new icons, use a 512x512 png with alpha background and `#dddddd` as foreground color.
